@@ -1126,6 +1126,7 @@
 
 #![cfg_attr(feature = "nightly", feature(doc_cfg))]
 #![cfg_attr(test, deny(warnings))]
+#![warn(missing_docs)]
 
 use downcast::*;
 use std::{
@@ -1465,6 +1466,7 @@ pub struct Times{
     range: TimesRange
 }
 
+#[doc(hidden)]
 impl Times {
     pub fn call(&self) -> Result<(), String> {
         let count = self.count.fetch_add(1, Ordering::Relaxed) + 1;
@@ -1472,7 +1474,11 @@ impl Times {
             if self.range.0.end == 1 {
                 Err("should not have been called".to_owned())
             } else {
-                Err(format!("called more than {} times", self.range.0.end - 1))
+                Err(format!(
+                    "called {} times which is more than the expected {}",
+                    count,
+                    self.range.0.end - 1
+                ))
             }
         } else {
             Ok(())
@@ -1483,6 +1489,11 @@ impl Times {
         self.range.0 = 0..usize::max_value();
     }
 
+    /// Return how many times this expectation has been called
+    pub fn count(&self) -> usize {
+        self.count.load(Ordering::Relaxed)
+    }
+
     /// Has this expectation already been called the maximum allowed number of
     /// times?
     pub fn is_done(&self) -> bool {
@@ -1531,6 +1542,7 @@ impl Times {
 #[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
 pub struct Key(any::TypeId);
 
+#[doc(hidden)]
 impl Key {
     pub fn new<T: 'static>() -> Self {
         Key(any::TypeId::of::<T>())
@@ -1628,6 +1640,7 @@ pub struct Sequence {
 }
 
 impl Sequence {
+    /// Create a new empty [`Sequence`]
     pub fn new() -> Self {
         Self::default()
     }
